@@ -1,7 +1,7 @@
 package Complete::Path;
 
-our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-01-02'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -239,10 +239,11 @@ sub complete_path {
             next if $filter_func && !$filter_func->($p);
 
             # process into final result
+            my $p0 = $p;
             substr($p, 0, $cut_chars) = '' if $cut_chars;
             $p = "$result_prefix$p" if length($result_prefix);
             unless ($p =~ /\Q$path_sep\E\z/) {
-                $p .= $path_sep if $is_dir_func->($p);
+                $p .= $path_sep if $is_dir_func->($p0);
             }
 
             push @res, $p;
@@ -266,7 +267,7 @@ Complete::Path - Complete path
 
 =head1 VERSION
 
-This document describes version 0.06 of Complete::Path (from Perl distribution Complete-Path), released on 2014-12-27.
+This document describes version 0.07 of Complete::Path (from Perl distribution Complete-Path), released on 2015-01-02.
 
 =head1 DESCRIPTION
 
@@ -348,10 +349,7 @@ This option mimics similar option in bash/readline: C<completion-map-case>.
 
 =back
 
-Return value:
-
- (array)
-
+Return value:  (array)
 =head1 TODO
 
 Recursive matching, e.g. **/Util to match: List/Util, CHI/Util,
@@ -383,7 +381,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
